@@ -148,7 +148,13 @@ static NSString *timeZoneFromString(NSString *zoneString)
 
 - (NSMutableArray*)dictionaryWithAAFFromFile:(NSString*)fileName
 {
+#ifdef __APPLE__
+    NSStringEncoding    *enc = nil;
+    if ( !(aafData = [NSString stringWithContentsOfFile:fileName
+                                           usedEncoding:enc error:NULL]) )
+#else
     if ( !(aafData = [NSString stringWithContentsOfFile:fileName]) )
+#endif
     {	NSLog(@"Couldn't load AAF file '%@'", fileName);
         return nil;
     }
