@@ -1,11 +1,12 @@
 /* AstroChart.m
  * The circular Astrology chart
  *
- * Copyright (C) 1998-2009 by vhf interservice GmbH
+ * Copyright (C) 1998-2010 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-12-19
- * modified: 2009-04-01 (radix: no date: draw composite only)
+ * modified: 2010-01-17 (-radix:...: scale chart to fit window)
+ *           2009-04-01 (radix: no date: draw composite only)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -31,6 +32,7 @@
 #include <VHFShared/VHFDictionaryAdditions.h>
 #include "../Cenon/functions.h"
 #include "../Cenon/Graphics.h"
+#include "../Cenon/DocWindow.h"
 #include "VTextAstroAdditions.h"	// convenient text methods
 #include "DocViewAstro.h"
 #include "AstroPrincipal.h"
@@ -527,7 +529,7 @@ typedef enum
             [line setColor:color];
             [group addObject:line];
 
-            string = (retro && v < 0.0) ? [NSString stringWithFormat:@"%@X", planetSymbol(planet)]
+            string = (retro && v < 0.0) ? (NSString*)[NSString stringWithFormat:@"%@X", planetSymbol(planet)]
                                         : planetSymbol(planet);
             [group addObject:[VText text:string
                                   center:NSMakePoint(p0.x-(radius*SCALE_MAX), cp.y)
@@ -595,7 +597,7 @@ typedef enum
 
             /* retrograde means against the regular direction */
             string = ( ((vDec < 0.0 && !flip) || (vDec > 0.0 && flip)) )
-                     ? [NSString stringWithFormat:@"%@X", planetSymbol(planet)]
+                     ? (NSString*)[NSString stringWithFormat:@"%@X", planetSymbol(planet)]
                      : planetSymbol(planet);
             [group addObject:[VText text:string
                                  center:NSMakePoint(p0.x-(radius*SCALE_MAX), cp.y)
@@ -1579,7 +1581,7 @@ typedef enum
  *   DATE
  *   TIME_#	time text for interval chart, optinally with interval (-#, +# in minutes)
  *
- * modified: 2006-10-09
+ * modified: 2010-04-22 (scale)
  */
 - (ChartTemplate)chartTemplate
 {
@@ -1591,6 +1593,16 @@ typedef enum
     VText	*text;
     BOOL	templateOK = NO;
 
+    /* Scale chart to fit window size */
+    if ( ! [(DocWindow*)[view window] hasCoordDisplay] )
+    {   NSRect  bounds = [view bounds], frame  = [[view window] frame];
+        float   oldScale = [view scaleFactor];
+        float   scale = (frame.size.width  / bounds.size.width) / oldScale;
+
+        if ( Diff(scale, 1.0) > TOLERANCE )
+            [[view document] scale:scale :scale withCenter:NSZeroPoint];
+    }
+
     chartTemplate.center = NSZeroPoint;
     chartTemplate.start  = chartTemplate.startC = NSZeroPoint;
     chartTemplate.radius = chartTemplate.radiusC = 0.0;
@@ -1764,7 +1776,8 @@ typedef enum
 }
 
 /* main calculation method
- * modified: 2009-04-01 (date = nil -> still draw composite)
+ * modified: 2010-01-17 (scale to fit window)
+ *           2009-04-01 (date = nil -> still draw composite)
  */
 - (void)radix:(NSCalendarDate*)date
     longitude:(float)longitude latitude:(float)latitude
@@ -1783,6 +1796,16 @@ typedef enum
 
     if ( ![[[view window] title] hasPrefix:CHART_PREFIX] )
         return;
+
+    /* scale to fit window */
+    if ( ! [(DocWindow*)[view window] hasCoordDisplay] )
+    {   NSRect  bounds = [view bounds], frame  = [[view window] frame];
+        float   oldScale = [view scaleFactor];
+        float   scale = (frame.size.width  / bounds.size.width) / oldScale;
+
+        [[view document] scale:scale :scale withCenter:NSZeroPoint];
+    }
+
     if (date)
         [(utc = [[date copy] autorelease]) setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
 
