@@ -1,11 +1,11 @@
 /* APChart.m
  * Controls the chart generation
  *
- * Copyright (C) 2001-2006 by vhf interservice GmbH
+ * Copyright (C) 2001-2008 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * Created:  2001-05-18
- * Modified: 2006-06-02 (Clock)
+ * Modified: 2008-02-02 (save settings from last run)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -57,27 +57,82 @@
                                name:AstroUpdateEvent
                              object:nil];
 
+    /* reload settings from last time */
+    {   NSUserDefaults  *defaults = [NSUserDefaults standardUserDefaults];
+        NSDateFormatter *dateFormatter = [[dateField cell] formatter];
+        NSString        *city, *name, *str;
+        float           lat, lon;
+
+        if ([defaults objectForKey:@"astroPanelChartLat"])
+        {
+            if ( (name = [defaults objectForKey:@"astroPanelChartName"]) )
+                [nameField setStringValue:name];
+            if ( (str = [defaults objectForKey:@"astroPanelChartDate"]) )
+            {   [[dateField cell] setFormatter:dateFormatter];
+                [dateField setStringValue:str];
+            }
+            if ( (str = [defaults objectForKey:@"astroPanelChartZone"]) )
+                [zoneField setStringValue:str];
+            if ( (city = [defaults objectForKey:@"astroPanelChartCity"]) )
+                [cityField setStringValue:city];
+            if ( (lat  = [defaults floatForKey: @"astroPanelChartLat"]) )
+                [latField setStringValue:vhfStringWithFloat(lat)];
+            if ( (lon  = [defaults floatForKey: @"astroPanelChartLon"]) )
+                [lonField setStringValue:vhfStringWithFloat(lon)];
+        }
+        if ([defaults objectForKey:@"astroPanelChartCLat"])
+        {
+            if ( (name = [defaults objectForKey:@"astroPanelChartCName"]) )
+                [cmpNameField setStringValue:name];
+            if ( (str = [defaults objectForKey:@"astroPanelChartCDate"]) )
+            {   [[cmpDateField cell] setFormatter:dateFormatter];
+                [cmpDateField setStringValue:str];
+            }
+            if ( (str = [defaults objectForKey:@"astroPanelChartCZone"]) )
+                [cmpZoneField setStringValue:str];
+            if ( (city = [defaults objectForKey:@"astroPanelChartCCity"]) )
+                [cmpCityField setStringValue:city];
+            if ( (lat  = [defaults floatForKey: @"astroPanelChartCLat"]) )
+                [cmpLatField setStringValue:vhfStringWithFloat(lat)];
+            if ( (lon  = [defaults floatForKey: @"astroPanelChartCLon"]) )
+                [cmpLonField setStringValue:vhfStringWithFloat(lon)];
+        }
+    }
+
     [self setComposite:self];
     [self update:self];
     return [super init];
 }
 
 - (void)update:sender
-{   NSString		*dateFormat = [[[AstroDate sharedInstance] dateFormat] stringByAppendingString:@" %H:%M"];
-    NSDateFormatter	*formatter = [[dateField cell] formatter];
+{   NSString            *dateFormat = [[[AstroDate sharedInstance] dateFormat] stringByAppendingString:@" %H:%M"];
+    NSDateFormatter     *dateFormatter = [[dateField cell] formatter];
+    //NSNumberFormatter   *zoneFormatter = [[zoneField cell] formatter];
 
     /* set date formatter */
-    if ( !formatter || ![dateFormat isEqual:[formatter dateFormat]] )
-    {   NSCalendarDate	*date;
+    if ( !dateFormat || ![dateFormat isEqual:[dateFormatter dateFormat]] )
+    {   NSCalendarDate	*date = [self date];
 
 //printf("Update: '%s' -> '%s'\n", [[formatter dateFormat] cString], [dateFormat cString]);
-        formatter = [[[NSDateFormatter alloc] initWithDateFormat:dateFormat allowNaturalLanguage:NO] autorelease];
+        dateFormatter = [[[NSDateFormatter  alloc] initWithDateFormat:dateFormat allowNaturalLanguage:NO] autorelease];
+/*        zoneFormatter = [[NSNumberFormatter alloc] autorelease];
+#ifdef __APPLE__
+        [zoneFormatter setFormatterBehavior:NSNumberFormatterBehavior10_0];
+#endif
+        [zoneFormatter setFormat:@"+##;+00;-##"];    // doesn't work!
+        [zoneFormatter setAllowsFloats:NO];*/
+
         date = [self date];
-        [[dateField cell] setFormatter:formatter];
+        [[dateField cell] setFormatter:dateFormatter];
         [dateField setStringValue:[date descriptionWithCalendarFormat:dateFormat]];
+        //[[zoneField cell] setFormatter:zoneFormatter];
+        [zoneField setStringValue:[[date descriptionWithCalendarFormat:@"%z"] substringToIndex:3]];
+
         date = [self compositeDate];
-        [[cmpDateField cell] setFormatter:formatter];
+        [[cmpDateField cell] setFormatter:dateFormatter];
         [cmpDateField setStringValue:[date descriptionWithCalendarFormat:dateFormat]];
+        //[[cmpZoneField cell] setFormatter:zoneFormatter];
+        [cmpZoneField setStringValue:[[date descriptionWithCalendarFormat:@"%z"] substringToIndex:3]];
     }
 }
 
@@ -101,18 +156,40 @@
 }
 
 /* start calculation of chart
- * modified: 2006-08-13
+ * modified: 2008-02-02 (save settings)
  */
 - (void)set:(id)sender
-{   NSCalendarDate	*utc = [self date];
-    float		lat = [latField floatValue], lon = [lonField floatValue];
-    Document		*doc = [(App*)NSApp currentDocument];
-    DocView		*view;
+{   NSCalendarDate  *date = [self date];
+    float           lat = [latField floatValue], lon = [lonField floatValue];
+    Document        *doc = [(App*)NSApp currentDocument];
+    DocView         *view;
 
     /* Astro Clock: use current time */
     if ( [sender isKindOfClass:[NSTimer class]] )
-    {   utc = [NSCalendarDate date];
-        [utc setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
+    {   int zoneOffset = [zoneField intValue] * 3600;
+
+        date = [NSCalendarDate date];
+        [date setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:zoneOffset]];
+    }
+    /* save settings */
+    else
+    {   NSUserDefaults  *defaults = [NSUserDefaults standardUserDefaults];
+
+        [defaults setObject:[nameField stringValue]         forKey:@"astroPanelChartName"];
+        [defaults setObject:[dateField stringValue]         forKey:@"astroPanelChartDate"];
+        [defaults setObject:[zoneField stringValue]         forKey:@"astroPanelChartZone"];
+        [defaults setObject:[self city]                     forKey:@"astroPanelChartCity"];
+        [defaults setObject:[NSNumber numberWithFloat:lat]  forKey:@"astroPanelChartLat"];
+        [defaults setObject:[NSNumber numberWithFloat:lon]  forKey:@"astroPanelChartLon"];
+        if ([self composite])
+        {
+            [defaults setObject:[cmpNameField stringValue]  forKey:@"astroPanelChartCName"];
+            [defaults setObject:[cmpDateField stringValue]  forKey:@"astroPanelChartCDate"];
+            [defaults setObject:[cmpZoneField stringValue]  forKey:@"astroPanelChartCZone"];
+            [defaults setObject:[cmpCityField stringValue]  forKey:@"astroPanelChartCCity"];
+            [defaults setObject:[cmpLatField  stringValue]  forKey:@"astroPanelChartCLat"];
+            [defaults setObject:[cmpLonField  stringValue]  forKey:@"astroPanelChartCLon"];
+        }
     }
 
     /* search a chart */
@@ -158,11 +235,11 @@
         astroChart = [[AstroChart astroChartWithView:view] retain];
     else if (astroChart && view && [[doc name] hasPrefix:CHART_PREFIX] )
         [astroChart setView:view];
-    [astroChart radix:utc longitude:lon latitude:lat city:[self city]
+    [astroChart radix:date longitude:lon latitude:lat city:[self city]
                 title:[nameField stringValue] composite:[self compositeData]];
 
     /* calculate chart for date */
-    [[NSNotificationCenter defaultCenter] postNotificationName:AstroDateSetNotification object:utc];
+    [[NSNotificationCenter defaultCenter] postNotificationName:AstroDateSetNotification object:date];
 }
 
 - (id)astroChart
@@ -188,24 +265,29 @@
     NSString		*dateFormat = [[AstroDate sharedInstance] dateFormat];
     NSString		*calendarFormat = [dateFormat stringByAppendingString:@" %H:%M"];
 
-    [date setTimeZone:[NSTimeZone timeZoneWithName:@"UTC"]];
     if ([compositeSwitch state])
-    {
+    {   int zoneOffset = [cmpZoneField intValue] * 3600;
+
+        [date setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:zoneOffset]];
         [cmpDateField setStringValue:[date descriptionWithCalendarFormat:calendarFormat]];
+        [cmpZoneField setStringValue:[[date descriptionWithCalendarFormat:@"%z"] substringToIndex:3]];
         [cmpDateField display];
     }
     else
-    {
+    {   int zoneOffset = [zoneField intValue] * 3600;
+
+        [date setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:zoneOffset]];
         [dateField setStringValue:[date descriptionWithCalendarFormat:calendarFormat]];
+        [zoneField setStringValue:[[date descriptionWithCalendarFormat:@"%z"] substringToIndex:3]];
         [dateField display];
     }
     [self set:self];
 }
 
 - (void)setDate:sender
-{   BOOL		control = [(App*)NSApp control];
-    int			m = 0;
-    NSCalendarDate	*date = [self date];
+{   BOOL            control = [(App*)NSApp control];
+    int             m = 0;
+    NSCalendarDate  *date = [self date];
 
     if ([sender isKindOfClass:[NSButton class]])	// buttons
     {   NSString	*dateFormat = [[AstroDate sharedInstance] dateFormat];
@@ -218,17 +300,18 @@
         }
         date = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:m seconds:0];
         [dateField setStringValue:[date descriptionWithCalendarFormat:calendarFormat]];
+        [zoneField setStringValue:[[date descriptionWithCalendarFormat:@"%z"] substringToIndex:3]];
         [dateField display];
     }
     [self set:self];
 }
 
 - (void)setEvent:(NSDictionary*)event
-{   id			dateValue;
-    NSString		*string;
-    NSCalendarDate	*date = nil;
-    NSString		*dateFormat = [[AstroDate sharedInstance] dateFormat];
-    NSString		*calendarFormat = [dateFormat stringByAppendingString:@" %H:%M"];
+{   id              dateValue;
+    NSString        *string;
+    NSCalendarDate  *date = nil;
+    NSString        *dateFormat = [[AstroDate sharedInstance] dateFormat];
+    NSString        *calendarFormat = [dateFormat stringByAppendingString:@" %H:%M"];
 
     [nameField setStringValue:[event stringForKey:@"name"]];
     [cityField setStringValue:[event stringForKey:@"city"]];
@@ -249,8 +332,8 @@
     }
     if (!date)
         date = [NSCalendarDate date];
-    [date setTimeZone:[NSTimeZone timeZoneWithName:@"UTC"]];
     [dateField setStringValue:[date descriptionWithCalendarFormat:calendarFormat]];
+    [zoneField setStringValue:[[date descriptionWithCalendarFormat:@"%z"] substringToIndex:3]];
     [self set:self];
 }
 
@@ -272,11 +355,12 @@
     return [lonField floatValue];
 }
 - (NSCalendarDate*)date
-{   NSString		*dateFormat = astroDateFormatForString([dateField stringValue]);
-    NSString		*calendarFormat = [dateFormat stringByAppendingString:@" %H:%M %Z"];
+{   NSString        *dateStr = [dateField stringValue], *tzStr = [zoneField stringValue];
+    NSString		*dateFormat = astroDateFormatForString([dateField stringValue]);
+    NSString		*calendarFormat = [dateFormat stringByAppendingString:@" %H:%M %z"];
     NSCalendarDate	*date;
 
-    date = [NSCalendarDate dateWithString:[NSString stringWithFormat:@"%@ UTC", [dateField stringValue]]
+    date = [NSCalendarDate dateWithString:[NSString stringWithFormat:@"%@ %@00", dateStr, tzStr]
                            calendarFormat:calendarFormat];
     if (!date)
         date = [NSCalendarDate date];
@@ -307,6 +391,7 @@
     [cmpLatField  setEnabled:[self composite]];
     [cmpLonField  setEnabled:[self composite]];
     [cmpDateField setEnabled:[self composite]];
+    [cmpZoneField setEnabled:[self composite]];
     [cmpBCButton  setEnabled:[self composite]];
     [[cmpBCButton superview] display];	// redraw composite switch ontop of box
 
@@ -326,7 +411,7 @@
 
     if ([sender isKindOfClass:[NSButton class]])	// buttons
     {   NSString	*dateFormat = [[AstroDate sharedInstance] dateFormat];
-        NSString	*calendarFormat = [dateFormat stringByAppendingString:@" %H:%M %Z"];
+        NSString	*calendarFormat = [dateFormat stringByAppendingString:@" %H:%M"];
 
         switch ([sender tag])
         {
@@ -335,6 +420,7 @@
         }
         date = [date dateByAddingYears:0 months:0 days:0 hours:0 minutes:m seconds:0];
         [cmpDateField setStringValue:[date descriptionWithCalendarFormat:calendarFormat]];
+        [cmpZoneField setStringValue:[[date descriptionWithCalendarFormat:@"%z"] substringToIndex:3]];
         [cmpDateField display];
     }
     [self set:self];	// calculate chart
@@ -362,17 +448,18 @@
     }
     if (!date)
         date = [NSCalendarDate date];
-    [date setTimeZone:[NSTimeZone timeZoneWithName:@"UTC"]];
     [cmpDateField setStringValue:[date descriptionWithCalendarFormat:calendarFormat]];
+    [cmpZoneField setStringValue:[[date descriptionWithCalendarFormat:@"%z"] substringToIndex:3]];
     [self set:self];
 }
 
 - (NSCalendarDate*)compositeDate
-{   NSString		*dateFormat = astroDateFormatForString([cmpDateField stringValue]);
-    NSString		*calendarFormat = [dateFormat stringByAppendingString:@" %H:%M %Z"];
+{   NSString        *dateStr = [cmpDateField stringValue], *tzStr = [cmpZoneField stringValue];
+    NSString		*dateFormat = astroDateFormatForString([cmpDateField stringValue]);
+    NSString		*calendarFormat = [dateFormat stringByAppendingString:@" %H:%M %z"];
     NSCalendarDate	*date;
 
-    date = [NSCalendarDate dateWithString:[NSString stringWithFormat:@"%@ UTC", [cmpDateField stringValue]]
+    date = [NSCalendarDate dateWithString:[NSString stringWithFormat:@"%@ %@00", dateStr, tzStr]
                            calendarFormat:calendarFormat];
     if (!date)
         date = [NSCalendarDate date];
@@ -399,23 +486,23 @@
  * notifications
  */
 
-/* notification send from EventManager
+/* notification send from EventManager (AstroUpdateEvent)
  * this can be send by other objects to calculate a chart
- * modified: 2005-08-06 (calculate composite, if flag setComposite is passed)
+ * modified: 2005-08-06
  */
 - (void)updateEvent:(NSNotification*)notification
-{   NSDictionary	*event = [notification object];
-    BOOL		setComposite = ([[notification userInfo] intForKey:@"composite"]) ? YES : NO;
+{   NSDictionary    *event = [notification object];
+    BOOL            setComposite = ([[notification userInfo] intForKey:@"composite"]) ? YES : NO;
 
     if ([event isKindOfClass:[NSDictionary class]])
     {   int	oldState = [compositeSwitch state];
 
         if (setComposite && oldState == 0)
-            [compositeSwitch setState:1];	// FIXME: better way to calculate composite ?
+            [compositeSwitch setState:1];	// FIXME: is there a better way to calculate composite ?
         if ([compositeSwitch state] || setComposite)
-            [self setCompositeEvent:event];
+            [self setCompositeEvent:event]; // calculate composite chart
         else
-            [self setEvent:event];
+            [self setEvent:event];          // calculate main chart
         if (setComposite && oldState == 0)
             [compositeSwitch setState:oldState];
     }
