@@ -1,7 +1,7 @@
 /* AstroPrincipal.m
  * Commander of the Astrology module
  *
- * Copyright (C) 2003-2007 by vhf interservice GmbH
+ * Copyright (C) 2003-2010 by Georg Fleischmann
  * Author:   Georg Fleischmann
  *
  * created:  2003-03-29
@@ -224,7 +224,7 @@ NSString *stringFromDeg(float deg)
     }
     [astroPanel setFrameUsingName:@"AstroPanel"];
     [astroPanel setFrameAutosaveName:@"AstroPanel"];
-    [astroPanel setBecomesKeyOnlyIfNeeded:YES];
+    [astroPanel setBecomesKeyOnlyIfNeeded:NO];
 /*#ifndef GNUSTEP_BASE_VERSION
     [astroPanel setFloatingPanel:YES];
 #endif*/
@@ -308,22 +308,49 @@ NSString *stringFromDeg(float deg)
 
 
 /* notification that a new document has been opened
+ * modified: 2010-04-22 (Map fixed)
+ *           2010-01-17 (remove scroller for Chart and scale to window size)
  */
 - (void)documentDidOpen:(NSNotification*)notification
 {   DocView	*view = [notification object];
 
     if ([view isMemberOfClass:[DocView class]])
-    {
+    {   NSString    *name = [(Document*)[view document] name];
+
         /* these methods are called for every view.
          * We have to make sure that we do our special stuff for our documents only.
          */
-        [view initMap];
+        if ( [name hasPrefix:@"Map"] )
+        {
+            [view initMap]; // this loads the map.plist and stores it into [view statusDict]
+            if ([view respondsToSelector:@selector(mapDocumentHasBeenSaved:)])
+            {   NSNotificationCenter    *notificationCenter = [NSNotificationCenter defaultCenter];
+                [notificationCenter addObserver:view
+                                       selector:@selector(mapDocumentHasBeenSaved:)
+                                           name:DocumentHasBeenSaved
+                                         object:nil];
+            }
+        }
 
-        if ([view respondsToSelector:@selector(mapDocumentHasBeenSaved:)])
-            [[NSNotificationCenter defaultCenter] addObserver:view
-                                                     selector:@selector(mapDocumentHasBeenSaved:)
-                                                         name:DocumentHasBeenSaved
-                                                       object:nil];
+        if ( ! [name hasPrefix:@"Chart"] && ! [name hasPrefix:@"Map"] )
+            return; // none of our documents
+
+        /* remove scrollers */
+        if ( ! [(DocWindow*)[view window] hasCoordDisplay] )
+        {   id  scrollView = [[view document] scrollView];
+
+            [scrollView setHasHorizontalScroller:NO];
+            [scrollView setHasVerticalScroller:  NO];
+
+            /* scale to fit window */
+            {   NSRect  bounds = [view bounds];
+                NSRect  frame  = [[view window] frame];
+                float   oldScale = [view scaleFactor];
+                float   scale = (frame.size.width  / bounds.size.width) / oldScale;
+
+                [[view document] scale:scale :scale withCenter:NSZeroPoint];
+            }
+        }
     }
     else
         NSLog(@"AstroPrincipal, notification send from object %@, shoult be DocView!", view);
@@ -402,10 +429,10 @@ NSString *stringFromDeg(float deg)
 {   NSCalendarDate	*date = [notification object];
 
     if ([date isKindOfClass:[NSCalendarDate class]])
-    {   int		i;
-        Document	*doc = [(App*)NSApp currentDocument];
-        DocView		*view = [doc documentView];
-        Map		*map;
+    {   int         i;
+        Document    *doc = [(App*)NSApp currentDocument];
+        DocView     *view = [doc documentView];
+        Map         *map;
 
         if ( ![[doc name] hasPrefix:MAP_PREFIX] )
         {
