@@ -1,11 +1,11 @@
 /* DocViewMap.h
  * Map Additions for DocView
  *
- * Copyright (C) 1998-2003 by vhf interservice GmbH
+ * Copyright (C) 1998-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-12-19
- * modified: 2003-07-14
+ * modified: 2006-02-19
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -35,13 +35,16 @@
 #define MAP_PREFIX	@"Map"	// the prefix of the filename of maps
 
 @interface DocView(Map)
+
 - (void)initMap;
 - (BOOL)isMap;
 
 - (void)setMapRadix:(NSEvent*)event;
 //- (void)setCIAMap:(CIAMap*)amap;
 - (CIAMap*)ciaMap;
-- (void)createMap:(NSPoint)center :(NSSize)size :(float)gridSize :(int)zodiacLines :(int)destinyLines;
+- (void)createMapWithCenter:(NSPoint)center size:(NSSize)size grid:(float)gridSize
+                   features:(NSDictionary*)features;
+
 @end
 
 #endif // VHF_H_DOCVIEWMAP
