@@ -1,11 +1,12 @@
 /* EventManager.m
  * controller class and files owner of the EventPanel
  *
- * Copyright (C) 2003-2009 by vhf interservice GmbH
+ * Copyright (C) 2003-2010 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2003-06-22
- * modified: 2009-02-28 (-add, -modify, -remove: test for nil events)
+ * modified: 2010-04-26 (-renameFolder:, -removeFolder: fixed)
+ *           2009-02-28 (-add, -modify, -remove: test for nil events)
  *           2006-01-15 (date formats)
  *
  * This program is free software; you can redistribute it and/or
@@ -32,6 +33,7 @@
 #include "../Cenon/App.h"
 #include "../Cenon/functions.h"
 #include "../Cenon/messages.h"
+#include "../Cenon/PreferencesMacros.h"
 #include "astroLocations.h"
 #include "astroMessages.h"
 #include "AstroPrincipal.h"
@@ -143,6 +145,7 @@ static int indexFromType(NSString *typeString)
 
         [self loadEvents];
         [eventBrowser loadColumnZero];
+        [eventPanel setDelegate:self];
     }
     [eventPanel makeKeyAndOrderFront:sender];
 }
@@ -167,11 +170,17 @@ static int indexFromType(NSString *typeString)
         NSLog(@"EventPanel, Add Folder: Name '%@' already in use!", name);
 }
 - (void)renameFolder:sender;
-{   int		folderIx = [eventBrowser selectedRowInColumn:0];
-    NSString	*name = [folderField stringValue];
+{   int         folderIx = [eventBrowser selectedRowInColumn:0];
+    NSString    *name = [folderField stringValue];
 
     if (name)
-    {
+    {   NSArray     *events;
+        NSString    *oldFolderName = [folders objectAtIndex:folderIx];
+
+        events = [eventDict objectForKey:oldFolderName];
+        [eventDict setObject:events forKey:name];
+        [eventDict removeObjectForKey:oldFolderName];
+
         [folders replaceObjectAtIndex:folderIx withObject:name];
         [eventBrowser loadColumnZero];
         [eventBrowser selectRow:folderIx inColumn:0];
@@ -187,6 +196,7 @@ static int indexFromType(NSString *typeString)
                                [folders objectAtIndex:folderIx]) == NSAlertDefaultReturn)
         return;
 
+    [eventDict removeObjectForKey:[folders objectAtIndex:folderIx]];
     [folders removeObjectAtIndex:folderIx];
     [eventBrowser loadColumnZero];
     [eventBrowser selectRow:(folderIx >= 1) ? folderIx-1 : 0 inColumn:0];
@@ -872,6 +882,47 @@ static int indexFromType(NSString *typeString)
         NSLog(@"EventManager, notification send from object %@, shoult be NSTimeZone!", tz);
 }
 
+/*
+ * Delegate methods
+ */
+
+/* allow resizing the window in grid
+ * created: 2010-01-16
+ */
+- (NSSize)windowWillResize:(NSWindow*)sender toSize:(NSSize)newSize
+{   int gridSize = Prefs_WindowGrid;
+
+    if ( gridSize ) // grid size
+    {
+        newSize.width  = floor((newSize.width +gridSize/2) / gridSize) * gridSize;
+        newSize.height = floor((newSize.height+gridSize/2) / gridSize) * gridSize;
+    }
+    return newSize;
+}
+/* allow moving of window in grid
+ * created: 2010-01-16
+ */
+/*- (NSRect)constrainFrameRect:(NSRect)frameRect toScreen:(NSScreen *)screen
+{   int gridSize = Prefs_WindowGrid;
+
+    frameRect = [super constrainFrameRect:frameRect toScreen:screen];
+    if ( gridSize )
+    {   frameRect.origin.x = floor((frameRect.origin.x+gridSize/2) / gridSize) * gridSize;
+        frameRect.origin.y = floor((frameRect.origin.y+gridSize/2) / gridSize) * gridSize;
+    }
+    return frameRect;
+}*/
+/*- (void)windowDidMove:(NSNotification *)notification
+{   int     gridSize = Prefs_WindowGrid;
+    id      window = [notification object];
+    NSRect  frameRect = [window frame];
+
+    if ( gridSize )
+    {   frameRect.origin.x = floor((frameRect.origin.x+gridSize/2) / gridSize) * gridSize;
+        frameRect.origin.y = floor((frameRect.origin.y+gridSize/2) / gridSize) * gridSize;
+    }
+    [window setFrameOrigin:frameRect.origin];
+}*/
 
 - (void)dealloc
 {
