@@ -1,11 +1,11 @@
 /* Ephemeris.h
  * front end object for the Swiss Ephemeris
  *
- * Copyright (C) 1999-2006 by Georg Fleischmann
+ * Copyright (C) 1999-2008 by Georg Fleischmann
  * Author:   Georg Fleischmann
  *
  * created:  1999-11-30
- * modified: 2006-02-19 (EPH_AC, EPH_MC)
+ * modified: 2008-08-23 (EPH_SYMBOLS added)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -34,39 +34,43 @@
 /* planet names and intersections in order of objects array
  * (see swephexp.h: SE_XXX)
  */
-#define OBJECTS	[NSArray arrayWithObjects:@"Sun", @"Moon", @"Mercury", @"Venus", @"Mars", @"Jupiter", @"Saturn", @"Uranus", @"Neptune", @"Pluto", @"Node", @"True Node", @"Apogee", @"True Apogee", @"Earth", @"Chiron", @"Pholus", @"Ceres", @"Pallas", @"Juno", @"Vesta", nil]
+#define OBJECTS     [NSArray arrayWithObjects:@"Sun", @"Moon", @"Mercury", @"Venus", @"Mars", @"Jupiter", @"Saturn", @"Uranus", @"Neptune", @"Pluto", @"Node", @"True Node", @"Apogee", @"True Apogee", @"Earth", @"Chiron", @"Pholus", @"Ceres", @"Pallas", @"Juno", @"Vesta", nil]
+#define EPH_SYMBOLS [NSArray arrayWithObjects:@"Sun", @"Moo", @"Mer", @"Ven", @"Mar", @"Jup", @"Sat", @"Ura", @"Nep", @"Plu", @"Nod", @"TNo", @"Apo", @"TAp", @"Ear", @"Chi", @"Pho", @"Cer", @"Pal", @"Jun", @"Ves", nil]
 
 #define DIR_NORMAL	0
 #define DIR_REVERSE	1
 
-/* 1:1 from SE_XXX */
+/* 1:1 from SE_XXX + AC, MC */
 typedef enum
 {
-    SUN        = SE_SUN,
-    MOON       = SE_MOON,
-    MERCURY    = SE_MERCURY,
-    VENUS      = SE_VENUS,
-    MARS       = SE_MARS,
-    JUPITER    = SE_JUPITER,
-    SATURN     = SE_SATURN,
-    URANUS     = SE_URANUS,
-    NEPTUNE    = SE_NEPTUNE,
-    PLUTO      = SE_PLUTO,
-    NODE       = SE_MEAN_NODE,
-    TRUENODE   = SE_TRUE_NODE,
-    APOGEE     = SE_MEAN_APOG,
-    TRUEAPOGEE = SE_TRUE_NODE,
-    CHIRON     = SE_CHIRON,
-    PHOLUS     = SE_PHOLUS,
-    CERES      = SE_CERES,
-    PALLAS     = SE_PALLAS,
-    JUNO       = SE_JUNO,
-    VESTA      = SE_VESTA,
-    AC         = 21,	// deprecated
-    EPH_AC     = 21,
-    MC         = 22,	// deprecated
-    EPH_MC     = 22,
-    EPH_NONE   = -1	// no object
+    EPH_SUN         = SE_SUN,
+    SUN             = SE_SUN,        // deprecated
+    EPH_MOON        = SE_MOON,
+    MOON            = SE_MOON,       // deprecated
+    EPH_MERCURY     = SE_MERCURY,
+    EPH_VENUS       = SE_VENUS,
+    EPH_MARS        = SE_MARS,
+    EPH_JUPITER     = SE_JUPITER,
+    EPH_SATURN      = SE_SATURN,
+    EPH_URANUS      = SE_URANUS,
+    EPH_NEPTUNE     = SE_NEPTUNE,
+    EPH_PLUTO       = SE_PLUTO,
+    EPH_NODE        = SE_MEAN_NODE,
+    EPH_TRUENODE    = SE_TRUE_NODE,
+    EPH_APOGEE      = SE_MEAN_APOG,
+    EPH_TRUEAPOGEE  = SE_OSCU_APOG,
+    EPH_CHIRON      = SE_CHIRON,
+    EPH_PHOLUS      = SE_PHOLUS,
+    EPH_CERES       = SE_CERES,
+    EPH_PALLAS      = SE_PALLAS,
+    EPH_JUNO        = SE_JUNO,
+    EPH_VESTA       = SE_VESTA,
+    EPH_AC          = 21,
+    AC              = 21,            // deprecated
+    EPH_MC          = 22,
+    MC              = 22,            // deprecated
+    EPH_COUNT       = 23,
+    EPH_NONE        = -1 // no object
 } EphemerisObjects;
 
 /* deprecated */
@@ -155,6 +159,10 @@ typedef struct
     NSArray	*objectNames;
     EphObject	objects[30];
     BOOL	calculateMeanNodes;
+
+    double	calcJD;		// last calculation date
+    BOOL	calcTopo;
+    float	calcLat, calcLon, calcElev;
 }
 
 - (id)init;
@@ -163,6 +171,8 @@ typedef struct
 - (void)setMeanNodes:(BOOL)flag;
 
 - (int)indexForObjectName:(NSString*)name;
++ (EphemerisObjects)indexForSymbol:(NSString*)symbol;
++ (NSString*)symbolAtIndex:(EphemerisObjects)objIx;
 
 /* date -> julian day (reference = -4712) */
 - (double)julianDayForDate:(NSCalendarDate*)utc bc:(BOOL)bcFlag;
@@ -174,6 +184,8 @@ typedef struct
 - (EphObject*)objectsAtUTC:(NSCalendarDate*)utc lat:(float)lat  lon:(float)lon;
 - (EphObject*)objectsAtUTC:(NSCalendarDate*)utc lat:(double)lat lon:(double)lon
                       elev:(double)alt topocentric:(BOOL)topocentric;
+- (BOOL)calculatedAtDate:(NSCalendarDate*)date tolerance:(int)tol
+                     lat:(float)lat lon:(float)lon elev:(float)elev topocentric:(BOOL)topo;
 /* year, month, day, ... methods */
 - (EphObject*)objectsAtYear:(int)year month:(int)month day:(int)day
                        hour:(int)hour minute:(int)minute second:(int)second
