@@ -1,11 +1,12 @@
 /* astroCommon.m
  * Common astronomical functions
  *
- * Copyright (C) 1998-2006 by vhf interservice GmbH
+ * Copyright (C) 1998-2009 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-11-06
- * modified: 2006-04-06 (Pholus ']' added, Pallas '[' corrected, new astro functions without NSCalendarDate)
+ * modified: 2009-04-08 (modulo())
+ *           2006-04-06 (Pholus ']' added, Pallas '[' corrected, new astro functions without NSCalendarDate)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -319,12 +320,12 @@ double *harmonicPattern1(int tableSize)
 /* "430'00" -> 4.5 or 4.5
  */
 float degFromString(NSString *degString)
-{   float		deg = 0.0;
-    NSScanner		*scanner = [NSScanner scannerWithString:degString];
-    NSCharacterSet	*digitSet  = [NSCharacterSet decimalDigitCharacterSet];
-    NSCharacterSet	*degreeSet = [NSCharacterSet characterSetWithCharactersInString:@" '\""];
-    NSString		*string;
-    NSRange		range;
+{   float           deg = 0.0;
+    NSScanner       *scanner = [NSScanner scannerWithString:degString];
+    NSCharacterSet  *digitSet  = [NSCharacterSet decimalDigitCharacterSet];
+    NSCharacterSet  *degreeSet = [NSCharacterSet characterSetWithCharactersInString:@" .'\""];
+    NSString        *string;
+    NSRange         range;
 
     range = [degString rangeOfCharacterFromSet:degreeSet];
     if ( !range.length )	// 4.5
@@ -406,7 +407,7 @@ NSCalendarDate *dateFromMJD(double mjd)
     sec = ((24.0*(jd+0.5-jd0) - hour) - min*60.0)/3600.0;
 
     date = [NSCalendarDate dateWithYear:year month:month day:day hour:hour minute:min second:sec
-                               timeZone:[NSTimeZone timeZoneWithName:@"UTC"]];
+                               timeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
     return date;
 }
 
@@ -451,6 +452,7 @@ double vhfJulianDay(NSCalendarDate *date)
 }
 
 /* Julian day (starting -4712)
+ * modified: 2008-10-16 (hour had integer conversion error = too big)
  */
 double vhfJulianDayFromInt(int yyyymmdd, int hhmm)
 {   int		year, month, day;
@@ -461,7 +463,7 @@ double vhfJulianDayFromInt(int yyyymmdd, int hhmm)
     month = yyyymmdd / 100;
     yyyymmdd -= yyyymmdd/100*100;
     day   = yyyymmdd;
-    hour  = (double)hhmm/100 + (double)(hhmm-(hhmm/100*100))/60.0;
+    hour  = (double)(hhmm/100) + (double)(hhmm-(hhmm/100*100)) / 60.0;
 
     if ( month <= 2 )
     {   month += 12;
@@ -505,7 +507,7 @@ int vhfIntDateFromJulianDay(double jd, int *yyyymmdd, int *hhmm)
     if (yyyymmdd)
         *yyyymmdd = yymmdd;
     if (hhmm)
-        *hhmm   = (int)hour*100 + (int)(hour/60.0);
+        *hhmm     = (int)hour*100 + (int)((hour-floor(hour))*60.0);
     return yymmdd;
 }
 
@@ -1066,6 +1068,13 @@ NSString *aspectSymbol(float deg, float orb)
     return nil;
 }
 
+/* remainder = num % denom
+ */
+/*double modulo(double num, double denom)
+{
+    return (num - floor(num / denom) * denom);
+}*/
+
 /* bring deg to interval [0, 360]
  */
 double mod360(double deg)
@@ -1093,7 +1102,7 @@ double angle180( double deg1, double deg2 )
 {   double ang = angle(deg1, deg2);
 
     if ( ang >= 180.0 )
-	ang = 360.0 - ang;
+        ang = 360.0 - ang;
     return ang;
 }
 /* angle = object1 - object2
