@@ -1,11 +1,11 @@
 /* astroLocations.h
  * Cenon file locations
  *
- * Copyright (C) 2003-2006 by vhf interservice GmbH
+ * Copyright (C) 2003-2007 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2003-03-29
- * modified: 2006-04-26
+ * modified: 2007-07-22
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -29,14 +29,16 @@
 #ifndef VHF_H_ASTROLOCATIONS
 #define VHF_H_ASTROLOCATIONS
 
-#define MODULENAME	@"Astro"	// the name of the module and name of library folder
+#define APPNAME     @"Cenon"            // the name of the application
+#define MODULENAME  @"Astro"            // the name of the module and name of library folder
+#define DOCU_ASTRO  @"CenonAstro.pdf"   // the name of the documentation file
 
 /* Astro Chart */
-#define CHART_FILE	@"Chart"	// default chart file
+#define CHART_FILE      @"Chart"        // default chart file
 
 /* Map */
-#define MAP_FILE	@"Map"		// default map file
+#define MAP_FILE        @"Map"          // default map file
 #define	MAP_INFOFILE	@"map.plist"	// predefined regions
-#define MAP_FOLDER	@"ciamaps"	// map folder
+#define MAP_FOLDER      @"ciamaps"      // map folder
 
 #endif // VHF_H_ASTROLOCATIONS
